@@ -3,14 +3,13 @@
 
 # run as root 
 
-# ar is a shortcut for addrepo, 
+# ar is a shortcut for addrepo,  
 # -f is a shortcut for --refresh and this is AUTO-refresh 
 
 
 # Note that there seems to be no simple way to add a repository if not yet present. 
 # Thus except at first run this script displays errors on repos already added. 
 
-<<<<<<< HEAD
 # codecs
 zypper ar https://ftp.fau.de/packman/suse/openSUSE_Tumbleweed/ Packman
 
@@ -31,35 +30,18 @@ zypper ar https://download.opensuse.org/repositories/home:netmax:distribution:op
 
 # for visual code
 rpm --import https://packages.microsoft.com/keys/microsoft.asc
-zypper addrepo https://packages.microsoft.com/yumrepos/vscode vscode#
-zypper addrepo https://packages.microsoft.com/config/opensuse/15/prod.repo
-=======
-#zypper ar --refresh https://ftp.gwdg.de/pub/linux/misc/packman/suse/openSUSE_Tumbleweed/ packman
+#ypper ar https://packages.microsoft.com/yumrepos/vscode vscodeOrg
+echo -e "[code]\nname=Visual Studio Code\nbaseurl=https://packages.microsoft.com/yumrepos/vscode\nenabled=1\nautorefresh=1\ntype=rpm-md\ngpgcheck=1\ngpgkey=https://packages.microsoft.com/keys/microsoft.asc" |sudo tee /etc/zypp/repos.d/vscode.repo > /dev/null
 
-# for svneverever
-zypper ar --refresh https://download.opensuse.org/repositories/openSUSE:Factory/standard/openSUSE:Factory.repo
-
-# for whatsapp 
-#zypper ar --refresh https://download.opensuse.org/repositories/home:plater/Tumbleweed/home:plater.repo
-zypper ar --refresh https://download.opensuse.org/repositories/network:im:whatsapp/openSUSE_Tumbleweed/network:im:whatsapp.repo
-
-# for skype
-#zypper addrepo --refresh https://download.opensuse.org/repositories/home:alveus:main/openSUSE_Tumbleweed/home:alveus:main.repo
-#zypper addrepo --refresh https://repo.skype.com/rpm/stable/skype-stable.repo
-
-
-
-
-# for visual code
-rpm --import https://packages.microsoft.com/keys/microsoft.asc
-zypper addrepo --refresh https://packages.microsoft.com/yumrepos/vscode vscode
->>>>>>> 03138a846ac97d114fc7b706e989cac62b8c9fef
+# The suse version is preferred, also it is much smaller. 
+# But at time of this writing, it does not work: problems with verification of signatures of extensions. 
+#zypper ar https://download.opensuse.org/repositories/devel:/tools:/ide:/vscode/openSUSE_Tumbleweed vscode
 
 # for sure interesting in itself. 
 # currently used for squeak (package squeak-vm) which is a smalltalk dialect 
-zypper addrepo https://download.opensuse.org/repositories/Education/openSUSE_Tumbleweed/Education.repo
+zypper ar https://download.opensuse.org/repositories/Education/openSUSE_Tumbleweed/Education.repo
 
-zypper addrepo https://download.opensuse.org/repositories/system:/snappy/openSUSE_Tumbleweed snappy
+zypper ar https://download.opensuse.org/repositories/system:/snappy/openSUSE_Tumbleweed snappy
 
 
 zypper --gpg-auto-import-keys refresh
@@ -69,11 +51,11 @@ zypper --gpg-auto-import-keys refresh
 #zypper addrepo https://download.opensuse.org/repositories/home:fstrba:maven/openSUSE_Tumbleweed/home:fstrba:maven.repo
 
 
-zypper addrepo -f https://pkg.jenkins.io/opensuse/ jenkins
+zypper ar -f https://pkg.jenkins.io/opensuse/ jenkins
 
 
 # for google chrome 
-zypper addrepo http://dl.google.com/linux/chrome/rpm/stable/x86_64 google-chrome
+zypper ar http://dl.google.com/linux/chrome/rpm/stable/x86_64 google-chrome
 
 rpm --import https://dl.google.com/linux/linux_signing_key.pub
 # if ! test linux_signing_key.pub ;
@@ -85,7 +67,7 @@ rpm --import https://dl.google.com/linux/linux_signing_key.pub
 
 
 # for epstool only 
-zypper addrepo https://download.opensuse.org/repositories/home:syntron/15.6/home:syntron.repo
+zypper ar https://download.opensuse.org/repositories/home:syntron/15.6/home:syntron.repo
 
 
 
