@@ -7,8 +7,9 @@
 # but excluding conda environments. 
 #/usr/bin/python3 -m pip install --upgrade pip
 
-pipx install diff-pdf-visually
+pipx install diff-pdf-visually #pdf-diff
 pipx install unoserver
+pipx commands
 #pip3 install -U python3-oct2py # library 
 pipx upgrade-all
 
